@@ -1,7 +1,7 @@
 NAME = 'fadapa'
-VERSION = '0.1'
-DESCRIPTION = 'Minimal & efficient parser for FastQC output data in Python'
-LONG_DESCRIPTION = '''Fadapa is a minimal and efficient parser for parsing Fastqc data. Using this module parsing FastQC results is quite easy and simple.'''
+VERSION = '0.2'
+DESCRIPTION = 'A minimal parser to parse FastQC output data in Python'
+LONG_DESCRIPTION = '''Fadapa is a minimal parser for parsing Fastqc data. Using this module parsing FastQC results is quite easy and simple.'''
 AUTHOR = 'Anand Reddy Pandikunta'
 EMAIL = 'anand21nanda@gmail.com'
 COPYRIGHT = 'Uncopyrighted'
